import { useMemo } from 'react';
import { fetchAppBranchVersionsPresentationAsync } from 'patchkit-generic-patcher2_ipc';
import useSWR from 'swr';
import { useRevalidate } from './revalidate';
/**
 * Hook that retrieves app branch versions presentation, also known as changelogs.
 * @param appId App ID.
 * @param appBranchId App branch ID.
 * @returns App branch versions presentation.
 */
export var useAppBranchVersionsPresentation = function (_a) {
    var appId = _a.appId, appBranchId = _a.appBranchId;
    var url = "app-branch-versions-presentation/".concat(appId, "/").concat(appBranchId);
    var data = useSWR(url, function () {
        return fetchAppBranchVersionsPresentationAsync({ appId: appId, appBranchId: appBranchId });
    }).data;
    var withoutUndefined = useMemo(function () {
        return Object.entries(data || {}).flatMap(function (_a) {
            var appBranchVersionId = _a[0], appVersionPresentation = _a[1];
            return appVersionPresentation !== undefined
                ? [[appBranchVersionId, appVersionPresentation]]
                : [];
        });
    }, [data]);
    return withoutUndefined;
};
/**
 * Hook that revalidates app branch versions presentation.
 * @param appId App ID.
 * @param appBranchId App branch ID.
 * @returns Revalidation function.
 */
export var useRevalidateAppBranchVersionsPresentation = function (_a) {
    var appId = _a.appId, appBranchId = _a.appBranchId;
    var url = "app-branch-versions-presentation/".concat(appId, "/").concat(appBranchId);
    var revalidate = useRevalidate();
    return function () { return revalidate(url); };
};
//# sourceMappingURL=app-branch-versions-presentations.js.map