import { fetchAppBranchLatestVersionInstallTaskPackagesEstimatedTotalBytesCountAsync } from 'patchkit-generic-patcher2_ipc';
import useSWR from 'swr';
import { useRevalidate } from '../revalidate';
/**
 * Hook that returns app install package size.
 * @param appId App ID.
 * @param appBranchId App branch ID.
 * @returns App install package size.
 */
export var useAppInstallPackageSize = function (_a) {
    var appId = _a.appId, appBranchId = _a.appBranchId;
    var url = "app-install-package-size/".concat(appId, "/").concat(appBranchId);
    var data = useSWR(url, function () {
        return fetchAppBranchLatestVersionInstallTaskPackagesEstimatedTotalBytesCountAsync({
            appId: appId,
            appBranchId: appBranchId,
        });
    }, {
        shouldRetryOnError: true,
        errorRetryCount: 3,
    }).data;
    return data;
};
/**
 * Hook that allows revalidating app install package size.
 * @param appId App ID.
 * @param appBranchId App branch ID.
 * @returns Revalidate app install package size function.
 */
export var useRevalidateAppInstallPackageSize = function (_a) {
    var appId = _a.appId, appBranchId = _a.appBranchId;
    var url = "app-install-package-size/".concat(appId, "/").concat(appBranchId);
    var revalidate = useRevalidate();
    return function () { return revalidate(url); };
};
//# sourceMappingURL=app-install-package-size.js.map