import { fetchAppBranchInstalledVersionUpdateTaskPackagesEstimatedTotalBytesCountAsync } from 'patchkit-generic-patcher2_ipc';
import useSWR from 'swr';
import { useRevalidate } from '../revalidate';
/**
 * Hook that returns app update package size.
 * @param appId App ID.
 * @param appBranchId App branch ID.
 * @returns App update package size.
 */
export var useAppUpdatePackageSize = function (_a) {
    var appId = _a.appId, appBranchId = _a.appBranchId;
    var url = "app-update-package-size/".concat(appId, "/").concat(appBranchId);
    var data = useSWR(url, function () {
        return fetchAppBranchInstalledVersionUpdateTaskPackagesEstimatedTotalBytesCountAsync({
            appId: appId,
            appBranchId: appBranchId,
        });
    }, {
        shouldRetryOnError: true,
        errorRetryCount: 3,
    }).data;
    return data;
};
/**
 * Hook that allows revalidating app update package size.
 * @param appId App ID.
 * @param appBranchId App branch ID.
 * @returns Revalidate app update package size function.
 */
export var useRevalidateAppUpdatePackageSize = function (_a) {
    var appId = _a.appId, appBranchId = _a.appBranchId;
    var url = "app-update-package-size/".concat(appId, "/").concat(appBranchId);
    var revalidate = useRevalidate();
    return function () { return revalidate(url); };
};
//# sourceMappingURL=app-update-package-size.js.map