import { fetchAppBranchVersionPresentationAsync } from 'patchkit-generic-patcher2_ipc';
import useSWR from 'swr';
import { useRevalidate } from '../revalidate';
/**
 * Hook that returns app version presentation. Also known as changelog. If version ID is not provided, latest version presentation is returned.
 * @param appId App ID.
 * @param appBranchId App branch ID.
 * @param versionId Version ID.
 * @returns App version presentation.
 */
export var useAppVersion = function (_a) {
    var appId = _a.appId, appBranchId = _a.appBranchId, versionId = _a.versionId;
    var url = versionId !== undefined ? "app-version/".concat(appId, "/").concat(appBranchId, "/").concat(versionId) : null;
    var data = useSWR(url, function () {
        return fetchAppBranchVersionPresentationAsync({ appId: appId, appBranchId: appBranchId, appBranchVersionId: versionId });
    }).data;
    return data;
};
/**
 * Hook that allows revalidating app version presentation.
 * @param appId App ID.
 * @param appBranchId App branch ID.
 * @param versionId Version ID.
 * @returns Revalidate app version presentation function.
 */
export var useRevalidateAppVersion = function (_a) {
    var appId = _a.appId, appBranchId = _a.appBranchId, versionId = _a.versionId;
    var url = versionId !== undefined ? "app-version/".concat(appId, "/").concat(appBranchId, "/").concat(versionId) : null;
    var revalidate = useRevalidate();
    return function () { return revalidate(url); };
};
//# sourceMappingURL=app-version.js.map