import { useIsInstallInQueue } from '../download-queue/is-install-in-queue';
import { useIsRepairInQueue } from '../download-queue/is-repair-in-queue';
import { useIsUpdateInQueue } from '../download-queue/is-update-in-queue';
import { useIsAppBeingInstalled } from './is-app-being-installed';
import { useIsAppBeingMoved } from './is-app-being-moved';
import { useIsAppBeingRepaired } from './is-app-being-repaired';
import { useIsAppBeingUninstalled } from './is-app-being-uninstalled';
import { useIsAppBeingUpdated } from './is-app-being-updated';
import { useIsAppInstalled } from './is-app-installed';
import { useIsAppStarted } from './is-app-started';
import { useWasAppInstallCancelled } from './was-app-install-cancelled';
import { useWasAppRepairCancelled } from './was-app-repair-cancelled';
import { useWasAppUpdateCancelled } from './was-app-update-cancelled';
/**
 * Hook that checks if app can be installed.
 * @param appId App ID.
 * @param appBranchId App branch ID.
 * @returns True if app can be installed.
 */
export var useCanInstall = function (_a) {
    var appId = _a.appId, appBranchId = _a.appBranchId;
    var isInstalled = useIsAppInstalled({ appId: appId, appBranchId: appBranchId });
    var isBeingUninstalled = useIsAppBeingUninstalled({ appId: appId, appBranchId: appBranchId });
    var isBeingInstalled = useIsAppBeingInstalled({ appId: appId, appBranchId: appBranchId });
    var isBeingUpdated = useIsAppBeingUpdated({ appId: appId, appBranchId: appBranchId });
    var isBeingRepaired = useIsAppBeingRepaired({ appId: appId, appBranchId: appBranchId });
    var isBeingMoved = useIsAppBeingMoved({ appId: appId, appBranchId: appBranchId });
    var isStarted = useIsAppStarted({ appId: appId, appBranchId: appBranchId });
    var wasLastInstallTaskCancelled = useWasAppInstallCancelled({ appId: appId, appBranchId: appBranchId });
    var wasLastUpdateTaskCancelled = useWasAppUpdateCancelled({ appId: appId, appBranchId: appBranchId });
    var wasLastRepairTaskCancelled = useWasAppRepairCancelled({ appId: appId, appBranchId: appBranchId });
    var isInstallInQueue = useIsInstallInQueue({ appId: appId, appBranchId: appBranchId });
    var isRepairInQueue = useIsRepairInQueue({ appId: appId, appBranchId: appBranchId });
    var isUpdateInQueue = useIsUpdateInQueue({ appId: appId, appBranchId: appBranchId });
    var canDoTask = !isInstalled &&
        !isBeingInstalled &&
        !isBeingUpdated &&
        !isBeingRepaired &&
        !isBeingMoved &&
        !isBeingUninstalled &&
        !isStarted &&
        !isInstallInQueue &&
        !isRepairInQueue &&
        !isUpdateInQueue &&
        !wasLastInstallTaskCancelled &&
        !wasLastUpdateTaskCancelled &&
        !wasLastRepairTaskCancelled;
    return canDoTask;
};
//# sourceMappingURL=can-install.js.map