import { useMemo } from 'react';
import { useAppState } from '../app-state';
/**
 * Hook that returns whether app is being moved.
 * @param appId App ID.
 * @param appBranchId App branch ID.
 * @returns Whether app is being moved.
 */
export var useIsAppBeingInstalled = function (_a) {
    var appId = _a.appId, appBranchId = _a.appBranchId;
    var appState = useAppState({ appId: appId });
    var isAppBeingInstalled = useMemo(function () {
        if (appState === undefined) {
            return false;
        }
        var branch = appState.branches[appBranchId];
        if (branch === undefined) {
            return false;
        }
        return branch.ongoingInstallTaskId !== undefined;
    }, [appState, appBranchId]);
    return isAppBeingInstalled;
};
//# sourceMappingURL=is-app-being-installed.js.map