import { useMemo } from 'react';
import { useAppState } from '../app-state';
/**
 * Hook that returns whether app is being moved.
 * @param appId App ID.
 * @param appBranchId App branch ID.
 * @returns Whether app is being moved.
 */
export var useIsAppBeingMoved = function (_a) {
    var appId = _a.appId, appBranchId = _a.appBranchId;
    var appState = useAppState({ appId: appId });
    var isAppBeingMoved = useMemo(function () {
        if (appState === undefined) {
            return false;
        }
        var branch = appState.branches[appBranchId];
        if (branch === undefined) {
            return false;
        }
        return branch.ongoingMoveTaskId !== undefined;
    }, [appState, appBranchId]);
    return isAppBeingMoved;
};
//# sourceMappingURL=is-app-being-moved.js.map