import { useMemo } from 'react';
import { useAppState } from '../app-state';
/**
 * Hook that returns whether app is being repaired.
 * @param appId App ID.
 * @param appBranchId App branch ID.
 * @returns Whether app is being repaired.
 */
export var useIsAppBeingRepaired = function (_a) {
    var appId = _a.appId, appBranchId = _a.appBranchId;
    var appState = useAppState({ appId: appId });
    var isAppBeingRepaired = useMemo(function () {
        if (appState === undefined) {
            return false;
        }
        var branch = appState.branches[appBranchId];
        if (branch === undefined) {
            return false;
        }
        return branch.ongoingRepairTaskId !== undefined;
    }, [appState, appBranchId]);
    return isAppBeingRepaired;
};
//# sourceMappingURL=is-app-being-repaired.js.map