import { useMemo } from 'react';
import { useAppState } from '../app-state';
/**
 * Hook that returns whether app is being uninstalled.
 * @param appId App ID.
 * @param appBranchId App branch ID.
 * @returns Whether app is being uninstalled.
 */
export var useIsAppBeingUninstalled = function (_a) {
    var appId = _a.appId, appBranchId = _a.appBranchId;
    var appState = useAppState({ appId: appId });
    var isAppBeingUninstalled = useMemo(function () {
        if (appState === undefined) {
            return false;
        }
        var branch = appState.branches[appBranchId];
        if (branch === undefined) {
            return false;
        }
        return branch.ongoingUninstallTaskId !== undefined;
    }, [appState, appBranchId]);
    return isAppBeingUninstalled;
};
//# sourceMappingURL=is-app-being-uninstalled.js.map