import { useMemo } from 'react';
import { useAppState } from '../app-state';
/**
 * Hook that returns whether app is being updated.
 * @param appId App ID.
 * @param appBranchId App branch ID.
 * @returns Whether app is being updated.
 */
export var useIsAppBeingUpdated = function (_a) {
    var appId = _a.appId, appBranchId = _a.appBranchId;
    var appState = useAppState({ appId: appId });
    var isAppBeingUpdated = useMemo(function () {
        if (appState === undefined) {
            return false;
        }
        var branch = appState.branches[appBranchId];
        if (branch === undefined) {
            return false;
        }
        return branch.ongoingUpdateTaskId !== undefined;
    }, [appState, appBranchId]);
    return isAppBeingUpdated;
};
//# sourceMappingURL=is-app-being-updated.js.map