import { useMemo } from 'react';
import { useAppState } from '../app-state';
/**
 * Hook that returns whether app is installed.
 * @param appId App ID.
 * @param appBranchId App branch ID.
 * @returns Whether app is installed.
 */
export var useIsAppInstalled = function (_a) {
    var appId = _a.appId, appBranchId = _a.appBranchId;
    var appState = useAppState({ appId: appId });
    var isAppInstalled = useMemo(function () {
        if (appState === undefined) {
            return false;
        }
        var branch = appState.branches[appBranchId];
        if (branch === undefined) {
            return false;
        }
        return branch.installedVersionId !== undefined;
    }, [appState, appBranchId]);
    return isAppInstalled;
};
//# sourceMappingURL=is-app-installed.js.map