import { useMemo } from 'react';
import { useAppState } from '../app-state';
import { useLatestVersionId, useRevalidateLatestVersionId } from './latest-version-id';
/**
 * Hook that returns whether app has new version available.
 * @param appId App ID.
 * @param appBranchId App branch ID.
 * @returns Whether app has new version available.
 */
export var useIsAppNewVersionAvailable = function (_a) {
    var appId = _a.appId, appBranchId = _a.appBranchId;
    var appState = useAppState({ appId: appId });
    var latestVersionId = useLatestVersionId({ appId: appId, appBranchId: appBranchId });
    var isAppNewVersionAvailable = useMemo(function () {
        if (appState === undefined) {
            return false;
        }
        if (latestVersionId === undefined) {
            return false;
        }
        var branch = appState.branches[appBranchId];
        if (branch === undefined) {
            return false;
        }
        if (branch.installedVersionId === undefined) {
            return false;
        }
        return branch.installedVersionId !== latestVersionId;
    }, [appState, appBranchId, latestVersionId]);
    return isAppNewVersionAvailable;
};
/**
 * Hook that returns revalidate function for isAppNewVersionAvailable hook. It can be used to implement check for updates button.
 * @param appId App ID.
 * @param appBranchId App branch ID.
 * @returns Revalidate function.
 */
export var useRevalidateIsAppNewVersionAvailable = function (_a) {
    var appId = _a.appId, appBranchId = _a.appBranchId;
    var revalidate = useRevalidateLatestVersionId({ appId: appId, appBranchId: appBranchId });
    return revalidate;
};
//# sourceMappingURL=is-app-new-version-available.js.map