import { fetchAppBranchLatestVersionIdInfoAsync } from 'patchkit-generic-patcher2_ipc';
import useSWR from 'swr';
import { useRevalidate } from '../revalidate';
/**
 * Hook that returns latest version ID for app branch.
 * @param appId App ID.
 * @param appBranchId App branch ID.
 * @returns Latest version ID.
 */
export var useLatestVersionId = function (_a) {
    var appId = _a.appId, appBranchId = _a.appBranchId;
    var url = "latest-version-id/".concat(appId, "/").concat(appBranchId);
    var data = useSWR(url, function () {
        return fetchAppBranchLatestVersionIdInfoAsync({ appId: appId, appBranchId: appBranchId });
    }).data;
    return data === null || data === void 0 ? void 0 : data.id;
};
/**
 * Hook that allows revalidating latest version ID for app branch. This is useful when you want to implement check for updates button.
 * @param appId App ID.
 * @param appBranchId App branch ID.
 * @returns Revalidate latest version ID function.
 */
export var useRevalidateLatestVersionId = function (_a) {
    var appId = _a.appId, appBranchId = _a.appBranchId;
    var url = "latest-version-id/".concat(appId, "/").concat(appBranchId);
    var revalidate = useRevalidate();
    return function () { return revalidate(url); };
};
//# sourceMappingURL=latest-version-id.js.map