import { useMemo } from 'react';
import { AppBranchInstallTaskError } from 'patchkit-generic-patcher2_foundation';
import { useAppState } from '../app-state';
/**
 * Hook that allows checking if app install was cancelled (paused).
 * @param appId App ID.
 * @param appBranchId App branch ID.
 * @returns Was app install cancelled.
 */
export var useWasAppInstallCancelled = function (_a) {
    var appId = _a.appId, appBranchId = _a.appBranchId;
    var appState = useAppState({ appId: appId });
    var wasAppInstallCanceled = useMemo(function () {
        var _a, _b, _c;
        if (appState === undefined) {
            return false;
        }
        var branch = appState.branches[appBranchId];
        if (branch === undefined) {
            return false;
        }
        if (branch.ongoingInstallTaskId !== undefined) {
            return false;
        }
        return (((_a = branch.lastFilesOperationTask) === null || _a === void 0 ? void 0 : _a.appBranchLastInstallTaskState) !== undefined &&
            ((_b = branch.lastFilesOperationTask) === null || _b === void 0 ? void 0 : _b.appBranchLastInstallTaskState.progress) !== undefined &&
            ((_c = branch.lastFilesOperationTask) === null || _c === void 0 ? void 0 : _c.appBranchLastInstallTaskState.error) ===
                AppBranchInstallTaskError.Cancelled &&
            branch.ongoingRepairTaskId === undefined);
    }, [appState, appBranchId]);
    return wasAppInstallCanceled;
};
//# sourceMappingURL=was-app-install-cancelled.js.map