import { useMemo } from 'react';
import { AppBranchRepairTaskError } from 'patchkit-generic-patcher2_foundation';
import { useAppState } from '../app-state';
/**
 * Hook that allows checking if app repair was cancelled (paused).
 * @param appId App ID.
 * @param appBranchId App branch ID.
 * @returns Was app repair cancelled.
 */
export var useWasAppRepairCancelled = function (_a) {
    var appId = _a.appId, appBranchId = _a.appBranchId;
    var appState = useAppState({ appId: appId });
    var wasAppRepairCancelled = useMemo(function () {
        var _a, _b, _c;
        if (appState === undefined) {
            return false;
        }
        var branch = appState.branches[appBranchId];
        if (branch === undefined) {
            return false;
        }
        if (branch.ongoingRepairTaskId !== undefined) {
            return false;
        }
        return (((_a = branch.lastFilesOperationTask) === null || _a === void 0 ? void 0 : _a.appBranchLastRepairTaskState) !== undefined &&
            ((_b = branch.lastFilesOperationTask) === null || _b === void 0 ? void 0 : _b.appBranchLastRepairTaskState.progress) !== undefined &&
            ((_c = branch.lastFilesOperationTask) === null || _c === void 0 ? void 0 : _c.appBranchLastRepairTaskState.error) ===
                AppBranchRepairTaskError.Cancelled);
    }, [appState, appBranchId]);
    return wasAppRepairCancelled;
};
//# sourceMappingURL=was-app-repair-cancelled.js.map