import { useMemo } from 'react';
import { AppBranchUpdateTaskError } from 'patchkit-generic-patcher2_foundation';
import { useAppState } from '../app-state';
/**
 * Hook that allows checking if app update was cancelled (paused).
 * @param appId App ID.
 * @param appBranchId App branch ID.
 * @returns Was app update cancelled.
 */
export var useWasAppUpdateCancelled = function (_a) {
    var appId = _a.appId, appBranchId = _a.appBranchId;
    var appState = useAppState({ appId: appId });
    var wasAppUpdateCanceled = useMemo(function () {
        var _a, _b, _c;
        if (appState === undefined) {
            return false;
        }
        var branch = appState.branches[appBranchId];
        if (branch === undefined) {
            return false;
        }
        if (branch.ongoingInstallTaskId !== undefined) {
            return false;
        }
        return (((_a = branch.lastFilesOperationTask) === null || _a === void 0 ? void 0 : _a.appBranchLastUpdateTaskState) !== undefined &&
            ((_b = branch.lastFilesOperationTask) === null || _b === void 0 ? void 0 : _b.appBranchLastUpdateTaskState.progress) !== undefined &&
            ((_c = branch.lastFilesOperationTask) === null || _c === void 0 ? void 0 : _c.appBranchLastUpdateTaskState.error) ===
                AppBranchUpdateTaskError.Cancelled);
    }, [appState, appBranchId]);
    return wasAppUpdateCanceled;
};
//# sourceMappingURL=was-app-update-cancelled.js.map