import { useContext, useMemo } from 'react';
import { LauncherStateContext } from './launcher-state';
/**
 * Hook for getting all apps available in the launcher instance.
 * @returns Map of all apps.
 */
export var useApps = function () {
    var currentLauncherState = useContext(LauncherStateContext).currentLauncherState;
    var apps = useMemo(function () {
        if (!currentLauncherState) {
            return new Map();
        }
        var appsKeys = Object.keys(currentLauncherState.apps);
        var definedApps = appsKeys
            .map(function (key) { return [key, currentLauncherState.apps[key]]; })
            .filter(function (a) { return a[1] !== undefined; });
        return new Map(definedApps);
    }, [currentLauncherState]);
    return apps;
};
//# sourceMappingURL=apps.js.map