/// <reference types="react" />
import { State } from 'patchkit-generic-patcher2_foundation';
import { AppBranchProps } from './app-branch-props';
interface UpdateOngoingTaskProps extends AppBranchProps {
    task: 'install' | 'uninstall' | 'repair' | 'update' | 'move';
}
/**
 * Hook that allows to get current state of the launcher.
 * @returns Current state of the launcher.
 * @returns Function that allows to mutate state of the launcher.
 */
export declare const useLauncherState: () => {
    data: State | undefined;
    mutate: import("swr").KeyedMutator<State>;
};
/**
 * Heart of the launcher. It contains state of tasks, apps and window.
 */
export declare const LauncherStateContext: import("react").Context<{
    /**
     * Current state of the launcher.
     */
    currentLauncherState: State | undefined;
    /**
     * Function that allows to update tasks with optimistic data. That gives us more responsive UI.
     * @param appBranchId Id of the app branch.
     * @param appId Id of the app.
     * @param task Task type that is going to be executed and updated.
     * @param updateFn Function that will be called while optimistic data is updated. It can be start install task, for example.
     * @returns Promise that will be resolved when task is resolved.
     */
    updateOngoingTask: ({ appBranchId, appId, task }: UpdateOngoingTaskProps, updateFn: () => Promise<void>) => Promise<void>;
    /**
     * Function that allows to update window state with optimistic data. That gives us more responsive UI.
     * @param isMaximized Is window maximized.
     * @param updateFn Function that will be called while optimistic data is updated. It can be start install task, for example.
     * @returns Promise that will be resolved when task is resolved.
     */
    updateWindowIsMaximized: (isMaximized: boolean, updateFn: () => Promise<void>) => Promise<void>;
}>;
export declare const LauncherStateContextProvider: ({ children }: {
    children: React.ReactNode;
}) => JSX.Element;
export {};
//# sourceMappingURL=launcher-state.d.ts.map