import { AppState } from 'patchkit-generic-patcher2_foundation';
import { AppBranchProps } from '../app-branch-props';
export declare class NotEnoughInstallSpaceError extends Error {
    constructor();
}
interface InstallHookAppProps extends AppBranchProps {
    path?: string;
}
interface InstallAppProps extends InstallHookAppProps {
    appState: AppState;
    appBranchAuthKey?: string;
}
/**
 * Default install app function. It checks available space and starts install task. It also marks app download and install date.
 * @param appId App ID.
 * @param appBranchId App branch ID.
 * @param appBranchAuthKey App branch auth key.
 * @param path App branch dir path.
 * @param appState App state.
 */
export declare const defaultInstallApp: ({ appId, appBranchId, appBranchAuthKey, path, appState, }: InstallAppProps) => Promise<void>;
/**
 * Hook for installing app. It updates launcher state with optimistic information about install start and then calls default install app function.
 * @param appId App ID.
 * @param appBranchId App branch ID.
 * @param path App branch dir path.
 * @returns Install app function. It takes optional path parameter which overrides path from hook props.
 */
export declare const useInstallApp: ({ appBranchId, appId, path }: InstallHookAppProps) => (overridePath?: string) => Promise<void>;
export {};
//# sourceMappingURL=install-app.d.ts.map