import { useEffect } from 'react';
import { Route, Routes, useLocation, useNavigate } from 'react-router';
import { useLauncherUpdateCheck } from 'patchkit-generic-patcher2_hooks';
import { AppChangelog, AppDownloads, AppPage, AppSettings } from 'views/app';
import { LayoutWrapper } from 'views/layout-wrapper';
import { Library } from 'views/library';

const singleAppInfo: {
  id: string;
  branchId: string;
} | undefined = undefined;

function App() {
  const location = useLocation();
  const navigate = useNavigate();
  useLauncherUpdateCheck();

  useEffect(
    () => {

      if (singleAppInfo === undefined) {

        return;
      }

      if (!location.pathname.startsWith(`/app/${singleAppInfo.id}/branch/${singleAppInfo.branchId}`)) {

        navigate(`/app/${singleAppInfo.id}/branch/${singleAppInfo.branchId}`);
      }
    },
    [
      location,
      navigate,
    ]
  );

  return (
    <div className="App">
      <LayoutWrapper isSingleAppLauncher={singleAppInfo !== undefined}>
        <Routes location={location}>
          <Route path="/" element={<Library />} />
          <Route path="/app/:appId/branch/:appBranchId" element={<AppPage />} />
          <Route path="/app/:appId/branch/:appBranchId/settings" element={<AppSettings />} />
          <Route path="/app/:appId/branch/:appBranchId/downloads" element={<AppDownloads />} />
          <Route path="/app/:appId/branch/:appBranchId/changelog" element={<AppChangelog />} />

          <Route path="*" element={<div>404</div>} />
        </Routes>
      </LayoutWrapper>
    </div>
  );
}

export default App;
