import { COLORS } from 'constant';
import styled from 'styled-components';

import { ColorsValueType } from 'types/theme-types';

interface StyleProps {
  backgroundColor?: ColorsValueType;
  backgroundImageUrl?: string;
}

const Background = styled.div<StyleProps>`
  width: 100%;
  height: 100%;
  background-color: ${(props) => props.backgroundColor || COLORS.GRAY};
  background-image: url(${(props) => props.backgroundImageUrl});
  transition: background-color 0.5s ease;
  background-size: cover;
  background-repeat: no-repeat;
  background-position: center;
  position: relative;
`;

const GradientOverlay = styled.div`
  background: linear-gradient(8.89deg, ${COLORS.GRAY} -3.54%, rgba(23, 24, 24, 0) 56.33%);
  position: absolute;
  width: 100%;
  height: 100%;
  top: 0;
  left: 0;
  z-index: 0;
`;

const Content = styled.div`
  width: 100%;
  height: 100%;
  z-index: 12;
  position: absolute;
  top: 0;
  left: 0;
`;

interface Props extends StyleProps {
  children?: React.ReactNode;
  className?: string;
}

export const AppBackground = ({
  backgroundColor,
  backgroundImageUrl,
  children,
  className,
}: Props) => (
  <Background
    backgroundColor={backgroundColor}
    backgroundImageUrl={backgroundImageUrl}
    className={className}
  >
    <GradientOverlay />
    <Content>{children}</Content>
  </Background>
);
