import { useNavigate } from 'react-router';
import {
  useAddInstallToQueue,
  useAppState,
  useCanInstall,
  useCanUninstall,
  useIsAppInstalled,
  useUninstallApp,
} from 'patchkit-generic-patcher2_hooks';
import styled from 'styled-components';

import { Card } from 'components/common/card';

const StyledDropdownElement = styled.p<{
  canInstall: boolean;
  canUninstall: boolean;
}>`
  padding: 0.5rem;
  margin: 0;
  border-radius: 0.25rem;
  font-weight: 700;
  cursor: ${(props) => (props.canInstall || props.canUninstall ? 'pointer' : 'not-allowed')};
`;

interface Props {
  appId: string;
  appBranchId: string;
}

export const AppCard = ({ appId, appBranchId }: Props) => {
  const navigate = useNavigate();
  const appState = useAppState({ appId });

  const addInstallTaskToQueue = useAddInstallToQueue({ appId, appBranchId });
  const uninstallApp = useUninstallApp({ appId, appBranchId });
  const isAppInstalled = useIsAppInstalled({ appId, appBranchId });
  const baseUrl = `/app/${appId}/branch/${appBranchId}`;

  const canUninstall = useCanUninstall({ appId, appBranchId });
  const canInstall = useCanInstall({ appId, appBranchId });

  return (
    <Card
      onClick={() => navigate(`/app/${appId}/branch/${appBranchId}`)}
      title={appState?.name || ''}
      imageUrl={appState?.bannerImageUrl || ''}
      dropdownElements={[
        <StyledDropdownElement
          canInstall={canInstall}
          canUninstall={canUninstall}
          key={isAppInstalled ? 'uninstall' : 'install'}
          onClick={
            isAppInstalled
              ? canUninstall
                ? () => uninstallApp().then(() => navigate(baseUrl))
                : undefined
              : canInstall
              ? () => {
                  addInstallTaskToQueue();
                  navigate(baseUrl);
                }
              : undefined
          }
        >
          {isAppInstalled ? 'Uninstall' : 'Install'}
        </StyledDropdownElement>,
      ]}
    />
  );
};
