import { COLORS } from 'constant';
import styled from 'styled-components';

import { Button } from 'components/common/button';
import { HalfTransparentDiv } from 'components/common/half-transparent-div';

interface StyleProps {
  iconWithFill?: boolean;
}

const Container = styled(HalfTransparentDiv)<StyleProps>`
  border-radius: 0.25rem;
  display: flex;
  align-items: center;
  justify-content: flex-start;
  padding: 1rem;
  width: min-content;

  p {
    color: ${COLORS.WHITE};
    font-size: 0.875rem;
    font-weight: 700;
    margin: 0;
    height: 1.5rem;
    display: flex;
    align-items: center;
    justify-content: center;
  }

  svg {
    height: 1.5rem;
    width: 1.5rem;
  }

  svg > path {
    ${(props) => (props.iconWithFill ? `fill: ${COLORS.WHITE}` : `stroke: ${COLORS.WHITE}`)};
  }

  &:hover {
    background-color: ${COLORS.LIGHT_GRAY};
  }
`;

interface Props extends StyleProps {
  onClick: () => void;
  children: JSX.Element; // <p> or <svg>
}

export const AppPageButton = ({ children, onClick, iconWithFill }: Props) => (
  <Button onClick={onClick}>
    <Container iconWithFill={iconWithFill}>{children}</Container>
  </Button>
);
