import { COLORS } from 'constant';
import styled from 'styled-components';

import { ExitIcon } from 'assets/icons';
import { Button } from 'components/common/button';
import { HalfTransparentDiv } from 'components/common/half-transparent-div';

const Container = styled(HalfTransparentDiv)`
  width: 100%;
  height: 100%;
  display: flex;
  flex-direction: column;
  border-radius: 0.25rem;
  margin-right: 1rem;
  margin-bottom: 1rem;
`;

const TitleBar = styled.div`
  display: flex;
  width: 100%;
  justify-content: space-between;
  align-items: center;
  padding: 1rem;

  p {
    margin: 0;
    font-size: 0.875rem;
    font-weight: 600;
    color: ${COLORS.DARK_GRAY_TEXT};
  }

  svg > path {
    stroke: ${COLORS.WHITE};
  }

  svg:hover > path {
    stroke: ${COLORS.HOVER_WHITE};
  }
`;

const Content = styled.div`
  width: 100%;
  height: 0%;
  flex: 2 2 auto;
  padding: 1rem;
`;

interface Props {
  title: string;
  onClose: () => void;
  children: JSX.Element | JSX.Element[];
}

export const AppPageOptionsContainer = ({ title, onClose, children }: Props) => (
  <Container>
    <TitleBar>
      <p>{title}</p>
      <Button onClick={onClose}>
        <ExitIcon />
      </Button>
    </TitleBar>
    <Content>{children}</Content>
  </Container>
);
