import { COLORS } from 'constant';
import styled from 'styled-components';

import { DirectoryIcon } from 'assets/icons';
import { Button } from 'components/common/button';

const Container = styled.div`
  width: 100%;
  display: flex;
  border-radius: 0.25rem;
  border: 1px solid ${COLORS.WHITE};
  height: 3rem;
`;

const Tooltip = styled.div`
  visibility: hidden;
  width: 30rem;
  background-color: ${COLORS.GRAY_INPUT};
  color: ${COLORS.WHITE};
  text-align: center;
  padding: 0.5rem;
  border-radius: 6px;
  height: min-content;

  position: absolute;
  z-index: 1;
  bottom: 125%;
  left: 50%;
  transform: translateX(-50%);
  word-wrap: break-word;

  opacity: 0;

  &::after {
    content: '';
    position: absolute;
    top: 100%;
    left: 50%;
    margin-left: 0.25rem;
    border-width: 0.25rem;
    border-style: solid;
    border-color: ${COLORS.GRAY_INPUT} transparent transparent transparent;
  }
`;

const TextContainer = styled.div`
  width: 100%;
  padding: 1rem;
  height: 3rem;
  display: flex;
  align-items: center;
  position: relative;

  input {
    width: 100%;
    overflow: auto;
    margin: 0;
    font-size: 1rem;
    font-weight: 600;
    color: ${COLORS.WHITE};
    text-overflow: ellipsis;
    white-space: nowrap;
    background-color: transparent;
    border: none;
    outline: none;
  }

  &:hover ${Tooltip} {
    visibility: visible;
    opacity: 1;
  }
`;

const ButtonContainer = styled.div`
  width: 3rem;
  height: 3rem;
  display: flex;
  align-items: center;
  justify-content: center;

  background-color: ${COLORS.WHITE};

  &:hover {
    background-color: ${COLORS.HOVER_WHITE};
  }

  svg > path {
    fill: ${COLORS.DARK_GRAY_TEXT};
  }
`;

interface Props {
  path: string;
  onClick: () => void;
}

export const AppPathInput = ({ path, onClick }: Props) => (
  <Container>
    <TextContainer>
      <input type="text" value={path} />
      <Tooltip>{path}</Tooltip>
    </TextContainer>
    <Button onClick={onClick}>
      <ButtonContainer>
        <DirectoryIcon />
      </ButtonContainer>
    </Button>
  </Container>
);
