import { COLORS } from 'constant';
import styled from 'styled-components';

import { Button } from 'components/common/button';

interface StyleProps {
  iconWithFill?: boolean;
}

const Container = styled.div<StyleProps>`
  border-radius: 0.25rem;
  border: 1px solid ${COLORS.WHITE};
  padding: 1rem 1.5rem 1rem 1rem;
  display: flex;
  align-items: center;

  &:hover {
    border: 1px solid ${COLORS.HOVER_WHITE};
  }

  &:hover > p {
    color: ${COLORS.HOVER_WHITE};
  }

  p {
    margin: 0;
    color: ${COLORS.WHITE};
    font-size: 1rem;
    font-weight: 600;
    margin-left: 0.75rem;
  }

  svg > path {
    ${(props) => (props.iconWithFill ? `fill: ${COLORS.WHITE}` : `stroke: ${COLORS.WHITE}`)};
  }
`;

interface Props extends StyleProps {
  text: string;
  onClick: () => void;
  icon: JSX.Element;
}

export const AppSettingsButton = ({ text, onClick, icon, iconWithFill }: Props) => (
  <Button onClick={onClick}>
    <Container iconWithFill={iconWithFill}>
      {icon}
      <p>{text}</p>
    </Container>
  </Button>
);
