import ReactMarkdown from 'react-markdown';
import { COLORS } from 'constant';
import remarkGfm from 'remark-gfm';
import styled from 'styled-components';

import { ExitIcon } from 'assets/icons';
import { Button } from 'components/common/button';
import { HalfTransparentDiv } from 'components/common/half-transparent-div';

const Background = styled(HalfTransparentDiv)`
  position: fixed;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  z-index: 100;
  padding: 2rem;
  display: flex;
  justify-content: center;
  align-items: center;
  opacity: 0;

  &.fade-enter {
    opacity: 0;
  }

  &.fade-enter.fade-enter-active {
    opacity: 1;
  }

  &.fade-enter-done {
    opacity: 1;
  }

  &.fade-exit {
    opacity: 1;
  }

  &.fade-exit.fade-exit-active {
    opacity: 0;
  }
`;

const ExitButton = styled(Button)`
  position: absolute;
  top: 0;
  right: 0;
  padding: 0.5rem;
  margin: 0.5rem;
  z-index: 102;
`;

const TextContainer = styled.div`
  padding: 2rem 2rem;
  border-radius: 0.25rem;
  display: flex;
  flex-direction: column;
  overflow: hidden;
  text-overflow: ellipsis;
  background-color: ${COLORS.DARK_GRAY};

  h3 {
    font-weight: 600;
    font-size: 1rem;
    margin: 0;
    color: ${COLORS.WHITE};
  }

  p {
    font-weight: 700;
    font-size: 0.875rem;
    margin: 0;
    color: ${COLORS.GRAT_TEXT};
  }

  a {
    text-decoration: none;
    color: ${COLORS.DARK_GRAY_TEXT};
    font-weight: 700;
    font-size: 0.875rem;
  }

  a:hover {
    color: ${COLORS.WHITE};
  }
`;

interface Props {
  onClose: () => void;
  markdownBody: string;
}

export const ArticleLightBox = ({ markdownBody, onClose }: Props) => {
  return (
    <Background onClick={onClose}>
      <ExitButton onClick={onClose}>
        <ExitIcon />
      </ExitButton>
      <TextContainer>
        <ReactMarkdown remarkPlugins={[remarkGfm]}>{markdownBody}</ReactMarkdown>
      </TextContainer>
    </Background>
  );
};
