import { useState } from 'react';
import { CSSTransition } from 'react-transition-group';
import { COLORS } from 'constant';
import styled from 'styled-components';

import { ArticleLightBox } from 'components/article-lightbox';
import { Button } from 'components/common/button';
import { HalfTransparentDiv } from 'components/common/half-transparent-div';

const Container = styled(HalfTransparentDiv)`
  border-radius: 0.25rem;
  display: flex;
  overflow: hidden;
  justify-content: flex-start;
  width: 14.25rem;
  height: 8rem;
`;

const TextContainer = styled.div`
  padding: 0.5rem 1rem;
  min-height: 100%;
  display: flex;
  flex-direction: column;
  justify-content: space-between;

  h3 {
    font-weight: 600;
    font-size: 1rem;
    margin: 0;
    color: ${COLORS.WHITE};
  }

  p {
    font-weight: 700;
    font-size: 0.875rem;
    margin: 0;
    color: ${COLORS.GRAT_TEXT};
  }

  a {
    text-decoration: none;
    color: ${COLORS.DARK_GRAY_TEXT};
    font-weight: 700;
    font-size: 0.875rem;
  }

  a:hover {
    color: ${COLORS.WHITE};
  }
`;

const StyledButton = styled(Button)`
  text-decoration: none;
  color: ${COLORS.DARK_GRAY_TEXT};
  font-weight: 700;
  font-size: 0.875rem;

  &:hover {
    color: ${COLORS.WHITE};
  }
`;

const StyledImg = styled.img`
  width: 6rem;
  height: 8rem;
  object-fit: cover;
`;

interface Props {
  title: string;
  subtitle?: string;
  imageUrl?: string;
  linkUrl?: string;
  markdownBody?: string;
}

export const ArticleTile = ({ title, subtitle, imageUrl, linkUrl, markdownBody }: Props) => {
  const [showLightBox, setShowLightBox] = useState(false);

  return (
    <Container>
      {imageUrl && <StyledImg src={imageUrl} />}
      <TextContainer>
        <h3>{title}</h3>
        {subtitle && <p>{subtitle}</p>}
        {markdownBody && (
          <StyledButton onClick={() => setShowLightBox(true)}>Read more</StyledButton>
        )}
      </TextContainer>
      {markdownBody && (
        <CSSTransition classNames="fade" timeout={300} in={showLightBox} mountOnEnter unmountOnExit>
          <>
            {
              <ArticleLightBox
                markdownBody={markdownBody}
                onClose={() => {
                  setShowLightBox(false);
                }}
              />
            }
          </>
        </CSSTransition>
      )}
    </Container>
  );
};
