import { useState } from 'react';
import { COLORS } from 'constant';
import styled from 'styled-components';

import { MoreIcon } from 'assets/icons';

import { Button } from '../button';
import { Dropdown } from '../dropdown';

const Container = styled.div`
  display: flex;
  flex-direction: column;
  justify-content: center;
  width: 15rem;
  height: 12.5rem;
  cursor: pointer;
  position: relative;
`;

const Image = styled.img`
  width: 100%;
  height: 10.5rem;
  border-radius: 0.25rem;
  object-fit: cover;
  filter: drop-shadow(0px 4px 4px rgba(0, 0, 0, 0.25));
`;

const Title = styled.p`
  color: ${COLORS.WHITE};
  font-size: 0.875rem;
  font-weight: 700;
  text-wrap: nowrap;
  text-overflow: ellipsis;
`;

const BottomRow = styled.div`
  display: flex;
  justify-content: space-between;
  align-items: center;
  width: 100%;
`;

interface ButtonProps {
  active?: boolean;
}

const StyledButton = styled(Button)<ButtonProps>`
  height: 1rem;
  width: 1.5rem;
  display: flex;
  align-items: center;
  justify-content: center;
  border-radius: 0.25rem;
  background-color: ${(props) => (props.active ? COLORS.LIGHT_GRAY : 'transparent')};

  &:hover {
    background-color: ${COLORS.LIGHT_GRAY};
  }
`;

interface Props {
  title: string;
  imageUrl: string;
  onClick?: () => void;
  className?: string;
  dropdownElements?: React.ReactNode;
}

export const Card = ({ title, imageUrl, onClick, className, dropdownElements }: Props) => {
  const [isDropdownOpen, setIsDropdownOpen] = useState(false);

  return (
    <Container className={className}>
      <Image src={imageUrl} onClick={onClick} />
      <BottomRow>
        <Title>{title}</Title>
        {dropdownElements && (
          <StyledButton
            onClick={(e) => {
              e.stopPropagation();
              setIsDropdownOpen(!isDropdownOpen);
            }}
            active={isDropdownOpen}
          >
            <MoreIcon />
          </StyledButton>
        )}
      </BottomRow>
      {dropdownElements && (
        <Dropdown isOpen={isDropdownOpen} toTop>
          {dropdownElements}
        </Dropdown>
      )}
    </Container>
  );
};
