import React from 'react';

import styles from './layout-stack.module.css';

type Props = {
  children?: JSX.Element[] | JSX.Element;
  rowElements: number;
  gapY?: number;
  gapX?: number;
  marginBottom?: number;
  marginTop?: number;
};

/**
 * @returns simple grid layout with row and column spacing
 */

export const LayoutStack = (props: Props) => {
  const childComponents = React.Children.toArray(props.children);
  const columnGap = props.gapX ? `${props.gapX}rem` : 0;
  const rowGap = props.gapY ? `${props.gapY}rem` : 0;
  const marginBottom = props.marginBottom ? `${props.marginBottom}rem` : 0;
  const marginTop = props.marginTop ? `${props.marginTop}rem` : 0;

  return (
    <div
      style={{
        columnGap,
        gridColumnGap: columnGap,
        rowGap,
        gridRowGap: rowGap,
        marginBottom,
        gridTemplateColumns: `repeat(${props.rowElements}, 1fr)`,
        marginTop,
      }}
      className={styles.grid}
    >
      {childComponents?.map((element, index) => (
        <div key={index}>{element}</div>
      ))}
    </div>
  );
};
