import { COLORS } from 'constant';
import styled from 'styled-components';

import { ExitIcon } from 'assets/icons';
import { Button } from 'components/common/button';
import { HalfTransparentDiv } from 'components/common/half-transparent-div';

const Background = styled(HalfTransparentDiv)`
  position: fixed;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  z-index: 100;
  padding: 2rem;
  display: flex;
  justify-content: center;
  align-items: center;
  opacity: 0;
  display: flex;
  justify-content: center;
  align-items: center;

  &.fade-enter {
    opacity: 0;
  }

  &.fade-enter.fade-enter-active {
    opacity: 1;
  }

  &.fade-enter-done {
    opacity: 1;
  }

  &.fade-exit {
    opacity: 1;
  }

  &.fade-exit.fade-exit-active {
    opacity: 0;
  }
`;

const Container = styled(HalfTransparentDiv)`
  border-radius: 0.5rem;
  width: 30rem;
  height: min-content;
  display: flex;
  flex-direction: column;
  justify-content: center;
`;

const TitleBar = styled.div`
  display: flex;
  width: 100%;
  justify-content: space-between;
  align-items: center;
  padding: 1rem;

  p {
    margin: 0;
    font-size: 0.875rem;
    font-weight: 600;
    color: ${COLORS.DARK_GRAY_TEXT};
  }

  svg > path {
    stroke: ${COLORS.WHITE};
  }

  svg:hover > path {
    stroke: ${COLORS.HOVER_WHITE};
  }
`;

const Content = styled.div`
  width: 100%;
  height: 0%;
  flex: 2 2 auto;
  padding: 0 1rem 1rem;
`;

const ButtonsContainer = styled.div`
  display: flex;
  width: 100%;
  justify-content: space-around;
  align-items: center;
  margin-top: 1rem;
`;

interface Props {
  title: string;
  onClose: () => void;
  buttons?: JSX.Element[];
  children: JSX.Element | JSX.Element[];
}

export const Popup = ({ title, onClose, buttons, children }: Props) => (
  <Background>
    <Container>
      <TitleBar>
        <p>{title}</p>
        <Button onClick={onClose}>
          <ExitIcon />
        </Button>
      </TitleBar>
      <Content>
        {children}
        {buttons && <ButtonsContainer>{buttons}</ButtonsContainer>}
      </Content>
    </Container>
  </Background>
);
