import { useEffect, useState } from 'react';
import { COLORS } from 'constant';
import styled from 'styled-components';

import { ResumePauseButton } from 'components/resume-pause-button';

const Container = styled.div`
  border-radius: 0.25rem;
  position: relative;
  width: 100%;
  height: 4rem;
  padding: 1rem;
  background-color: ${COLORS.PROGRESS_BAR_BACKGROUND};
  display: flex;
  align-items: center;
  overflow: hidden;

  & > button {
    z-index: 2;
  }
`;

interface FillProps {
  width?: number;
  positionLeft?: number;
}

const Fill = styled.div<FillProps>`
  border-radius: 0.25rem;
  position: absolute;
  top: 0;
  left: ${(props) =>
    props.positionLeft !== undefined ? `${props.positionLeft * 1.4 - 20}%` : '0'};
  width: ${(props) => (props.width !== undefined ? props.width : 20)}%;
  background-color: ${COLORS.BLUE};
  height: 100%;
  ${(props) => props.positionLeft !== undefined && 'transition: none;'};
`;

const Text = styled.p`
  font-size: 0.875rem;
  font-weight: 600;
  color: ${COLORS.WHITE};
  margin: 0;
  z-index: 2;
  margin-left: 0.5rem;
`;

interface Props {
  progressPercentage?: number;
  taskName?: string;
  onPaused?: () => void;
  onResumed?: () => void;
  isPaused?: boolean;
}

export const ProgressBar = ({
  progressPercentage,
  taskName,
  onPaused,
  onResumed,
  isPaused,
}: Props) => {
  const [positionLeft, setPositionLeft] = useState(0);

  useEffect(() => {
    const interval = setInterval(() => {
      setPositionLeft((leftPosition) => (leftPosition + 1) % 100);
    }, 15);

    return () => clearInterval(interval);
  }, []);

  return (
    <Container>
      <Fill
        width={progressPercentage !== undefined ? progressPercentage : undefined}
        positionLeft={progressPercentage !== undefined ? undefined : positionLeft}
      />
      {(onPaused || onResumed) && progressPercentage !== undefined && (
        <ResumePauseButton isPaused={isPaused} onPause={onPaused} onResume={onResumed} />
      )}
      <Text>{taskName}</Text>
      {progressPercentage !== undefined && <Text>{progressPercentage.toFixed(0)}%</Text>}
    </Container>
  );
};
