import { useEffect, useState } from 'react';
import { COLORS } from 'constant';
import styled from 'styled-components';

import { ColorsValueType } from 'types/theme-types';

const Container = styled.div`
  position: relative;
  width: 100%;
  height: 0.25rem;
  background-color: ${COLORS.LIGHT_GRAY};
  border-radius: 0.125rem;
  overflow: hidden;
`;

interface StyleProps {
  width: number;
  leftPosition?: number;
  backgroundColor?: ColorsValueType;
}

const Bar = styled.div<StyleProps>`
  position: absolute;
  top: 0;
  left: ${(props) =>
    props.leftPosition !== undefined ? `${props.leftPosition * 1.4 - 10}%` : '0'};
  width: ${(props) => props.width || 0}%;
  height: 100%;
  background-color: ${(props) => props.backgroundColor || COLORS.BLUE};}};
  border-radius: 0.125rem;
`;

interface Props {
  progressPercentage?: number;
  backgroundColor?: ColorsValueType;
}

export const SmallProgressBar = ({ progressPercentage, backgroundColor }: Props) => {
  const [leftPosition, setLeftPosition] = useState(0);

  useEffect(() => {
    const interval = setInterval(() => {
      setLeftPosition((v) => (v + 1) % 100);
    }, 50);

    return () => clearInterval(interval);
  }, []);

  return (
    <Container>
      <Bar
        width={progressPercentage || 10}
        backgroundColor={backgroundColor}
        leftPosition={progressPercentage === undefined ? leftPosition : undefined}
      />
    </Container>
  );
};
