import { COLORS } from 'constant';
import styled from 'styled-components';

import { Button } from 'components/common/button';
import { ColorsValueType } from 'types/theme-types';

interface StyleProps {
  backgroundColor: ColorsValueType;
  hoverBackgroundColor: ColorsValueType;
  iconWithFill?: boolean;
  hasIcon?: boolean;
}

const Container = styled.div<StyleProps>`
  padding: 1rem ${(props) => (props.hasIcon ? '1.5rem' : '1rem')} 1rem 1rem;
  border-radius: 0.25rem;
  background-color: ${(props) => props.backgroundColor};

  display: flex;
  align-items: center;
  justify-content: center;

  &:hover {
    background-color: ${(props) => props.hoverBackgroundColor};
  }

  svg > path {
    ${(props) => (props.iconWithFill ? `fill: ${COLORS.WHITE}` : `stroke: ${COLORS.WHITE}`)};
  }

  svg {
    width: 2rem;
    height: 2rem;
    padding: 0;
  }

  p {
    margin: 0;
    color: ${COLORS.WHITE};
    ${(props) => props.hasIcon && 'margin-left: 0.75rem;'}
    font-size: 1.125rem;
    font-weight: 300;
  }
`;

interface Props extends StyleProps {
  icon?: JSX.Element;
  text: string;
  onClick: () => void;
}

export const TaskButton = ({
  icon,
  text,
  onClick,
  backgroundColor,
  hoverBackgroundColor,
  iconWithFill,
}: Props) => {
  return (
    <Button
      onClick={(e) => {
        e.stopPropagation();
        onClick();
      }}
    >
      <Container
        hasIcon={icon !== undefined}
        iconWithFill={iconWithFill}
        backgroundColor={backgroundColor}
        hoverBackgroundColor={hoverBackgroundColor}
      >
        {icon}
        <p>{text}</p>
      </Container>
    </Button>
  );
};
