import styled from 'styled-components';

import { ExitIcon } from 'assets/icons';
import { Button } from 'components/common/button';
import { HalfTransparentDiv } from 'components/common/half-transparent-div';

const Background = styled(HalfTransparentDiv)`
  position: fixed;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  z-index: 100;
  padding: 2rem;
  display: flex;
  justify-content: center;
  align-items: center;
  opacity: 0;

  &.fade-enter {
    opacity: 0;
  }

  &.fade-enter.fade-enter-active {
    opacity: 1;
  }

  &.fade-enter-done {
    opacity: 1;
  }

  &.fade-exit {
    opacity: 1;
  }

  &.fade-exit.fade-exit-active {
    opacity: 0;
  }
`;

const ExitButton = styled(Button)`
  position: absolute;
  top: 0;
  right: 0;
  padding: 0.5rem;
  margin: 0.5rem;
  z-index: 102;
`;

const StyledImage = styled.img`
  width: 100%;
  object-fit: contain;
  height: 100%;
`;

interface Props {
  imageUrl?: string;
  videoUrl?: string;
  onClose: () => void;
}

export const LightBox = ({ imageUrl, videoUrl, onClose }: Props) => {
  const ytId = videoUrl?.split('v=')[1];
  const embedUrl = `https://www.youtube.com/embed/${ytId}?mute=0&autoplay=0&controls=1&loop=1&playlist=${ytId}`;

  return (
    <Background onClick={onClose}>
      <ExitButton onClick={onClose}>
        <ExitIcon />
      </ExitButton>
      {imageUrl && <StyledImage src={imageUrl} onClick={(e) => e.stopPropagation()} />}
      {videoUrl && <iframe src={embedUrl} width="100%" height="100%" frameBorder="0" />}
    </Background>
  );
};
