import { useEffect, useState } from 'react';
import { COLORS } from 'constant';
import styled from 'styled-components';

import { ExitIcon, SearchIcon } from 'assets/icons';
import { Button } from 'components/common/button';

const StyledInput = styled.input`
  border: none;
  background-color: transparent;
  color: ${COLORS.GRAT_TEXT};
  font-size: 0.875rem;
  font-weight: 500;

  &:focus {
    border: none;
    color: ${COLORS.WHITE};
    outline: none;
  }
`;

const Container = styled.div`
  width: 15rem;
  height: 2.5rem;
  border-radius: 0.25rem;
  background-color: ${COLORS.GRAY_INPUT};
  color: ${COLORS.GRAT_TEXT};
  padding: 0.5rem;
  font-size: 0.875rem;
  font-weight: 500;
  display: flex;
  align-items: center;

  &:focus-within {
    background-color: ${COLORS.LIGHT_GRAY};
  }

  svg > path {
    stroke: ${COLORS.GRAT_TEXT};
  }
`;

const StyledButton = styled(Button)`
  width: 1.5rem;
  height: 1.5rem;
  border-radius: 0.25rem;
  align-items: center;
  justify-content: center;
  margin-left: 0.5rem;
  self-align: flex-end;
  display: flex;
  visibility: hidden;

  ${Container}:focus-within & {
    visibility: visible;
  }

  &:hover {
    background-color: ${COLORS.DARK_GRAY};
  }

  svg > path {
    stroke: ${COLORS.WHITE};
  }
`;

interface Props {
  onChanged: (value: string) => void;
}

export const SearchInput = ({ onChanged }: Props) => {
  const [isFocused, setIsFocused] = useState(false);
  const [value, setValue] = useState('');

  useEffect(() => {
    onChanged(value);
  }, [value, onChanged]);

  return (
    <Container className={isFocused ? 'active' : undefined}>
      <SearchIcon />
      <StyledInput
        onFocus={() => setIsFocused(true)}
        onBlur={() => setIsFocused(false)}
        type="text"
        placeholder="Search"
        value={value}
        onChange={(e) => setValue(e.target.value)}
      />
      <StyledButton onClick={() => setValue('')}>
        <ExitIcon />
      </StyledButton>
    </Container>
  );
};
