import { COLORS } from 'constant';
import styled from 'styled-components';

import { Button } from 'components/common/button';
import { HalfTransparentDiv } from 'components/common/half-transparent-div';

interface StyleProps {
  active?: boolean;
}

const Container = styled(HalfTransparentDiv)<StyleProps>`
  ${(props) => props.active && `background-color: ${COLORS.LIGHT_GRAY};`}
  border-left: 0.25rem solid ${(props) => (props.active ? COLORS.LIGHT_BLUE : 'transparent')};
  border-radius: 0.25rem;
  width: 9.5rem;
  height: 3.5rem;
  display: flex;
  align-items: center;
  justify-content: flex-start;
  padding: 0 1rem;

  p {
    color: ${COLORS.WHITE};
    font-size: 0.875rem;
    font-weight: 700;
    margin: 0;
    margin-left: 0.5rem;
  }

  &:hover {
    background-color: ${COLORS.LIGHT_GRAY};
  }
`;

interface Props extends StyleProps {
  onClick: () => void;
  className?: string;
  title: string;
  icon: React.ReactNode;
}

export const SideBarButton = ({ active, icon, onClick, className, title }: Props) => (
  <Button onClick={onClick} className={className}>
    <Container active={active}>
      {icon}
      <p>{title}</p>
    </Container>
  </Button>
);
