import { useLocation, useNavigate } from 'react-router';
import { COLORS } from 'constant';
import { useApps, useAppState } from 'patchkit-generic-patcher2_hooks';
import styled from 'styled-components';

import { AllAppsIcon, DownloadIcon } from 'assets/icons';
import { HalfTransparentDiv } from 'components/common/half-transparent-div';
import { SideBarButton } from 'components/side-bar-button';

const Container = styled.div`
  display: flex;
  flex-direction: column;
  margin: 0 2rem;
  height: 100%;
  max-width: 9.5rem;
`;

const AppsContainer = styled(HalfTransparentDiv)`
  border-radius: 4px;
  display: flex;
  flex-direction: column;
  width: 100%;
  margin-top: 1.5rem;
  height: 33rem;
  overflow-y: auto;
`;

const NoAppsContainer = styled.div`
  width: 100%;
  height: 100%;
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;

  p {
    color: ${COLORS.GRAT_TEXT};
    font-size: 0.875rem;
    font-weight: 700;
    text-align: center;
  }

  svg {
    width: 3rem;
    height: 3rem;
  }

  svg path {
    stroke: ${COLORS.GRAT_TEXT};
  }
`;

export const SideBar = () => {
  // TODO: apps
  const location = useLocation();
  const navigate = useNavigate();

  const apps = useApps();

  const installedApps = Array.from(apps.entries()).filter(([_, state]) => {
    return state.branches['main']?.installedVersionId;
  });

  return (
    <Container>
      <SideBarButton
        title="All Games"
        icon={<AllAppsIcon />}
        onClick={() => navigate('/')}
        active={location.pathname === '/'}
      />
      <AppsContainer>
        {installedApps.length > 0 ? (
          installedApps.map(([appId, _]) => (
            <InstalledAppSidebarItem key={appId} appId={appId} appBranchId={'main'} />
          ))
        ) : (
          <NoAppsContainer>
            <DownloadIcon />
            <p>Installed games will appear here</p>
          </NoAppsContainer>
        )}
      </AppsContainer>
    </Container>
  );
};

const StyledIcon = styled.img`
  border-radius: 0.25rem;
  width: 1.5rem;
  height: 1.5rem;
  object-fit: cover;
`;

const InstalledAppSidebarItem = ({
  appId,
  appBranchId,
}: {
  appId: string;
  appBranchId: string;
}) => {
  const appState = useAppState({ appId });
  const navigate = useNavigate();
  const location = useLocation();
  const url = `/app/${appId}/branch/${appBranchId}`;

  return (
    <SideBarButton
      title={appState?.name || ''}
      icon={<StyledIcon src={appState?.iconImageUrl} />}
      active={location.pathname.includes(url)}
      onClick={() => navigate(url)}
    />
  );
};
