import { useContext, useEffect } from 'react';
import { useLocation } from 'react-router';
import { PacmanLoader } from 'react-spinners';
import { CSSTransition, TransitionGroup } from 'react-transition-group';
import { COLORS } from 'constant';
import { LauncherStateContext, useAppPresentation, useApps } from 'patchkit-generic-patcher2_hooks';
import styled from 'styled-components';

import { AppBackground } from 'components/app-background';
import { SideBar } from 'components/side-bar';
import { TitleBar } from 'components/title-bar';
import { AppBackgroundContext } from 'context/app-background-context';

// TODO: unleash the sizing
const WindowView = styled.div`
  width: 80rem;
  height: 45rem;
  overflow: hidden;
`;

const MainSection = styled.div`
  display: flex;
  align-items: stretch;
  padding: 2.5rem 0 2rem;
`;

const Content = styled.div`
  margin-right: 2rem;
  flex: 2 2 auto;
  width: 50%;
  position: relative;

  & > * {
    position: absolute;
    top: 0;
    left: 0;
  }
`;

export const LayoutWrapper = ({ isSingleAppLauncher, children }: { isSingleAppLauncher: boolean; children: React.ReactNode | React.ReactNode[] }) => {
  // const { appId } = useParams();
  const { backgroundImageUrl, setBackgroundImageUrl } = useContext(AppBackgroundContext);
  const apps = useApps();
  const location = useLocation();
  const launcherState = useContext(LauncherStateContext);

  const appId = location.pathname.split('/')[2];

  const appPresentation = useAppPresentation({ appId });

  useEffect(() => {
    // HACK

    if (appId && appPresentation) {
      const app = apps.get(appId);
      setBackgroundImageUrl(
        appPresentation?.customFields['1fb9e022-96a1-4b5a-a8f6-b8262dd51943']?.value ||
        app?.bannerImageUrl,
      );
    } else {
      setBackgroundImageUrl(undefined);
    }
  }, [appId, appPresentation, appPresentation?.customFields, apps, setBackgroundImageUrl]);

  return (
    <WindowView>
      <AppBackground backgroundImageUrl={backgroundImageUrl}>
        <TitleBar />
        <MainSection>
          {launcherState !== undefined && Array.from(apps.keys()).length > 0 ? (
            <>
              {!isSingleAppLauncher ? <SideBar /> : <div style={{ width: '2.5rem', height: '37rem' }} />}
              <Content>
                <TransitionGroup component={null}>
                  <CSSTransition key={location.key} classNames="fade" timeout={250}>
                    {children}
                  </CSSTransition>
                </TransitionGroup>
              </Content>
            </>
          ) : (
            <PacmanLoader
              color={COLORS.BLUE}
              style={{
                position: 'absolute',
                top: '50%',
                left: '50%',
                transform: 'translate(-50%, -50%)',
              }}
            />
          )}
        </MainSection>
      </AppBackground>
    </WindowView>
  );
};
