import { useState } from 'react';
import { useApps } from 'patchkit-generic-patcher2_hooks';
import styled from 'styled-components';

import PatchKitLogoWhite from 'assets/patchkit_logo_white.png';
import { AppCard } from 'components/app-card/app-card';
import { LibraryGrid } from 'components/library-grid';
import { SearchInput } from 'components/search-input';

const Container = styled.div`
  display: flex;
  flex-direction: column;
  height: 100%;
`;

const FilterBar = styled.div`
  display: flex;
  flex-direction: row;
  justify-content: space-between;
  align-items: center;
  padding: 0 2rem;
`;

const PatchKitLogoContainer = styled.div`
  position: absolute;
  cursor: pointer;
  bottom: 32px;
  right: 64px;
  display: flex;
  flex-direction: column;
  align-items: center;
  color: white;
  gap: 8px;
  font-weight: 500;
`;

const PatchKitLogo = styled.img`
  height: 32px;
`;

export const Library = () => {
  const apps = useApps();
  const [searchFilter, setSearchFilter] = useState('');

  const filteredApps = Array.from(apps.entries())
    .filter(([appId, appState]) => {
      const appBranchState = appState.branches['main'];
      return appBranchState !== undefined;
    })
    .filter((app) => {
      if (searchFilter === '') {
        return true;
      }

      return app[1]?.name?.toLowerCase().includes(searchFilter.toLowerCase());
    });

  const renderGridElements = () => {
    return filteredApps.map(([id, _]) => <AppCard key={id} appId={id} appBranchId={'main'} />);
  };

  return (
    <Container>
      <FilterBar>
        <div></div>
        <SearchInput onChanged={(val) => setSearchFilter(val)} />
      </FilterBar>
      <LibraryGrid>{renderGridElements()}</LibraryGrid>
      <PatchKitLogoContainer
        onClick={() => window.open('https://patchkit.net', '_blank')}
      >
        Launcher powered by
        <PatchKitLogo
          src={PatchKitLogoWhite}
        />
      </PatchKitLogoContainer>
    </Container>
  );
};
